@@ -432,6 +432,9 @@ class Cursor(object):
         for col in range(1, self._meta.getColumnCount() + 1):
             sqltype = self._meta.getColumnType(col)
             converter = self._converters.get(sqltype, _unknownSqlTypeConverter)
+            if str(converter.__name__) == "_unknownSqlTypeConverter":
+                if "SQLCLI_DEBUG" in os.environ:
+                    warnings.warn("Unknown JDBC convert with constant value " + str(sqltype) )
             v = converter(self._rs, col)
             row.append(v)
         return tuple(row)
@@ -599,7 +602,9 @@ _DEFAULT_CONVERTERS = {
     'TIMESTAMP': _to_datetime,
     'TIME': _to_time,
     'DATE': _to_date,
+    'VARBINARY': _to_binary,
     'BINARY': _to_binary,
+    'LONGVARBINARY': _to_binary,
     'DECIMAL': _java_to_py_bigdecimal(),
     'NUMERIC': _java_to_py_bigdecimal(),
     'DOUBLE': _java_to_py('doubleValue'),
